# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from typing_extensions import Literal

from ....._models import BaseModel

__all__ = ["Feedback"]


class Feedback(BaseModel):
    id: str

    rating: Literal["positive", "negative"]

    comment: Optional[str] = None
