# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from pydantic import Field as FieldInfo

from ...._models import BaseModel

__all__ = ["TenantDeleteResponse"]


class TenantDeleteResponse(BaseModel):
    success: bool

    tenant_key: str = FieldInfo(alias="tenantKey")
